"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TokenStatus = void 0;
var require_1 = __importDefault(require("./require"));
var jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
var http_errors_1 = __importDefault(require("http-errors"));
var TokenStatus;
(function (TokenStatus) {
    TokenStatus[TokenStatus["Valid"] = 0] = "Valid";
    TokenStatus[TokenStatus["Missing"] = 1] = "Missing";
    TokenStatus[TokenStatus["Expired"] = 2] = "Expired";
    TokenStatus[TokenStatus["Invalid"] = 3] = "Invalid";
    TokenStatus[TokenStatus["NotValidYet"] = 4] = "NotValidYet";
})(TokenStatus = exports.TokenStatus || (exports.TokenStatus = {}));
var Token = /** @class */ (function () {
    function Token(encodedJwt, secretOrPublicKey) {
        var _this = this;
        this.requireValid = function () {
            switch (_this.status) {
                case TokenStatus.Valid:
                    return;
                case TokenStatus.Missing:
                    throw new http_errors_1.default.Unauthorized('Token missing');
                case TokenStatus.Expired:
                    throw new http_errors_1.default.Unauthorized('Token expired');
                case TokenStatus.NotValidYet:
                    throw new http_errors_1.default.Unauthorized('Token not active yet');
                case TokenStatus.Invalid:
                    throw new http_errors_1.default.Unauthorized('Token invalid');
            }
        };
        if (encodedJwt === undefined) {
            this.status = TokenStatus.Missing;
            return;
        }
        try {
            var payload = jsonwebtoken_1.default.verify(encodedJwt, secretOrPublicKey);
            if (typeof payload === 'string') {
                throw new Error('Does not support string payloads');
            }
            this.roles = payload.roles;
            this.claims = payload;
            this.status = TokenStatus.Valid;
        }
        catch (err) {
            switch (err.name) {
                case 'TokenExpiredError':
                    this.status = TokenStatus.Expired;
                    break;
                case 'NotBeforeError':
                    this.status = TokenStatus.NotValidYet;
                    break;
                default:
                    this.status = TokenStatus.Invalid;
            }
        }
    }
    Object.defineProperty(Token.prototype, "require", {
        get: function () {
            return new require_1.default(this);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Token.prototype, "valid", {
        get: function () {
            return this.status === TokenStatus.Valid;
        },
        enumerable: false,
        configurable: true
    });
    return Token;
}());
exports.default = Token;
//# sourceMappingURL=token.js.map